CssParser class

CSS Parser for parsing inline styles and style attributes

Constructors

CssParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseInlineStyle(String cssString, {TextStyle? baseStyle}) TextStyle?
Parse inline CSS style string to TextStyle
parsePropertiesMap(Map<String, String> properties, {TextStyle? baseStyle}) TextStyle?
Parse CSS properties from a Map to TextStyle