CssStylesheet class

CSS Stylesheet manager that parses and stores CSS rules

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllVariables() Map<String, String>
Get all CSS variables
getCssVariable(String variableName) String?
Get CSS variable value
getStylesForSelector(String selector) Map<String, String>
Get styles for a specific selector (e.g., ".markdown-body", ".markdown-body h1")
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveCssVariables(String value) String
Resolve CSS variable references (var(--variable-name))
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String cssContent) CssStylesheet
Parse CSS from string