CssTheme class

CSS Theme manager for applying stylesheet-based themes

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllVariables() Map<String, String>
Get all CSS variables
getColor(String variableName) Color?
Get color from CSS variable
getTextStyle(String selector, {TextStyle? baseStyle}) TextStyle?
Get TextStyle for a specific selector
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMarkdownTheme({required BuildContext context, TextStyle? baseStyle}) MarkdownThemeData
Create a MarkdownTheme from this CSS theme
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromAsset(String assetPath) Future<CssTheme>
Load CSS theme from asset file
fromString(String cssContent) CssTheme
Load CSS theme from string