MarkdownThemeData class

Markdown theme data extracted from CSS

Constructors

MarkdownThemeData({TextStyle? h1Style, TextStyle? h2Style, TextStyle? h3Style, TextStyle? h4Style, TextStyle? h5Style, TextStyle? h6Style, TextStyle? pStyle, TextStyle? codeStyle, TextStyle? blockquoteStyle, TextStyle? linkStyle, TextStyle? strongStyle, TextStyle? emStyle, Color? backgroundColor, Color? foregroundColor, Color? accentColor, Color? borderColor})
const

Properties

accentColor Color?
final
backgroundColor Color?
final
blockquoteStyle TextStyle?
final
borderColor Color?
final
codeStyle TextStyle?
final
emStyle TextStyle?
final
foregroundColor Color?
final
h1Style TextStyle?
final
h2Style TextStyle?
final
h3Style TextStyle?
final
h4Style TextStyle?
final
h5Style TextStyle?
final
h6Style TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
linkStyle TextStyle?
final
pStyle TextStyle?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strongStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited